@@ -1,6 +1,9 @@
 package Markdent::Dialect::GitHub::BlockParser;
 {
-  $Markdent::Dialect::GitHub::BlockParser::VERSION = '0.22';
+  $Markdent::Dialect::GitHub::BlockParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Dialect::GitHub::BlockParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -64,7 +67,7 @@ sub _match_fenced_code_block {
 
 # ABSTRACT: Block parser for GitHub Markdown
 
-
+__END__
 
 =pod
 
@@ -74,7 +77,7 @@ Markdent::Dialect::GitHub::BlockParser - Block parser for GitHub Markdown
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -93,15 +96,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
