@@ -1,6 +1,9 @@
 package Markdent::Dialect::GitHub::SpanParser;
 {
-  $Markdent::Dialect::GitHub::SpanParser::VERSION = '0.22';
+  $Markdent::Dialect::GitHub::SpanParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Dialect::GitHub::SpanParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -81,7 +84,7 @@ around _text_end_res => sub {
 
 # ABSTRACT: Span parser for GitHub Markdown
 
-
+__END__
 
 =pod
 
@@ -91,7 +94,7 @@ Markdent::Dialect::GitHub::SpanParser - Span parser for GitHub Markdown
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -110,15 +113,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
