@@ -1,6 +1,9 @@
 package Markdent::Dialect::Theory::BlockParser;
 {
-  $Markdent::Dialect::Theory::BlockParser::VERSION = '0.22';
+  $Markdent::Dialect::Theory::BlockParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Dialect::Theory::BlockParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -451,7 +454,7 @@ sub _match_table_cell {
 
 # ABSTRACT: Block parser for Theory's proposed Markdown extensions
 
-
+__END__
 
 =pod
 
@@ -461,7 +464,7 @@ Markdent::Dialect::Theory::BlockParser - Block parser for Theory's proposed Mark
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -488,15 +491,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
