@@ -1,6 +1,9 @@
 package Markdent::Dialect::Theory::SpanParser;
 {
-  $Markdent::Dialect::Theory::SpanParser::VERSION = '0.22';
+  $Markdent::Dialect::Theory::SpanParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Dialect::Theory::SpanParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -23,7 +26,7 @@ around _build_escapable_chars => sub {
 
 # ABSTRACT: Span parser for Theory's proposed Markdown extensions
 
-
+__END__
 
 =pod
 
@@ -33,7 +36,7 @@ Markdent::Dialect::Theory::SpanParser - Span parser for Theory's proposed Markdo
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -53,15 +56,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
