@@ -1,6 +1,9 @@
 package Markdent::Event::StartHTMLTag;
 {
-  $Markdent::Event::StartHTMLTag::VERSION = '0.22';
+  $Markdent::Event::StartHTMLTag::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Event::StartHTMLTag::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -32,7 +35,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: An event for the start of an inline HTML tag
 
-
+__END__
 
 =pod
 
@@ -42,7 +45,7 @@ Markdent::Event::StartHTMLTag - An event for the start of an inline HTML tag
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -73,15 +76,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
