@@ -1,6 +1,9 @@
 package Markdent::Event::StartTableCell;
 {
-  $Markdent::Event::StartTableCell::VERSION = '0.22';
+  $Markdent::Event::StartTableCell::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Event::StartTableCell::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -38,7 +41,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: An event for the start of a table cell
 
-
+__END__
 
 =pod
 
@@ -48,7 +51,7 @@ Markdent::Event::StartTableCell - An event for the start of a table cell
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -84,15 +87,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
