@@ -1,6 +1,9 @@
 package Markdent::Handler::CaptureEvents;
 {
-  $Markdent::Handler::CaptureEvents::VERSION = '0.22';
+  $Markdent::Handler::CaptureEvents::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Handler::CaptureEvents::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -31,7 +34,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Captures events for replaying later
 
-
+__END__
 
 =pod
 
@@ -41,7 +44,7 @@ Markdent::Handler::CaptureEvents - Captures events for replaying later
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -74,15 +77,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
