@@ -1,6 +1,9 @@
 package Markdent::Handler::HTMLFilter;
 {
-  $Markdent::Handler::HTMLFilter::VERSION = '0.22';
+  $Markdent::Handler::HTMLFilter::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Handler::HTMLFilter::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -40,7 +43,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Filters out HTML events from the event stream
 
-
+__END__
 
 =pod
 
@@ -50,7 +53,7 @@ Markdent::Handler::HTMLFilter - Filters out HTML events from the event stream
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -87,15 +90,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
