@@ -1,6 +1,9 @@
 package Markdent::Handler::HTMLStream::Document;
 {
-  $Markdent::Handler::HTMLStream::Document::VERSION = '0.22';
+  $Markdent::Handler::HTMLStream::Document::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Handler::HTMLStream::Document::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -51,7 +54,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Turns Markdent events into a complete HTML document
 
-
+__END__
 
 =pod
 
@@ -61,7 +64,7 @@ Markdent::Handler::HTMLStream::Document - Turns Markdent events into a complete
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -110,15 +113,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
