@@ -1,6 +1,9 @@
 package Markdent::Handler::HTMLStream::Fragment;
 {
-  $Markdent::Handler::HTMLStream::Fragment::VERSION = '0.22';
+  $Markdent::Handler::HTMLStream::Fragment::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Handler::HTMLStream::Fragment::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -21,7 +24,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Turns Markdent events into an HTML fragment
 
-
+__END__
 
 =pod
 
@@ -31,7 +34,7 @@ Markdent::Handler::HTMLStream::Fragment - Turns Markdent events into an HTML fra
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -77,15 +80,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
