@@ -1,6 +1,9 @@
 package Markdent::Handler::MinimalTree;
 {
-  $Markdent::Handler::MinimalTree::VERSION = '0.22';
+  $Markdent::Handler::MinimalTree::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Handler::MinimalTree::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -469,7 +472,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A Markdent handler which builds a tree
 
-
+__END__
 
 =pod
 
@@ -479,7 +482,7 @@ Markdent::Handler::MinimalTree - A Markdent handler which builds a tree
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -513,15 +516,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
