@@ -1,6 +1,9 @@
 package Markdent::Parser;
 {
-  $Markdent::Parser::VERSION = '0.22';
+  $Markdent::Parser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Parser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -226,7 +229,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A markdown parser
 
-
+__END__
 
 =pod
 
@@ -236,7 +239,7 @@ Markdent::Parser - A markdown parser
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -318,15 +321,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
