@@ -1,6 +1,9 @@
 package Markdent::Parser::SpanParser;
 {
-  $Markdent::Parser::SpanParser::VERSION = '0.22';
+  $Markdent::Parser::SpanParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Parser::SpanParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -965,7 +968,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: Span parser for standard Markdown
 
-
+__END__
 
 =pod
 
@@ -975,7 +978,7 @@ Markdent::Parser::SpanParser - Span parser for standard Markdown
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -1013,15 +1016,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
