@@ -1,6 +1,9 @@
 package Markdent::Role::AnyParser;
 {
-  $Markdent::Role::AnyParser::VERSION = '0.22';
+  $Markdent::Role::AnyParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::AnyParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -63,7 +66,7 @@ sub _debug_look_for {
 
 # ABSTRACT: A role for block and span parsers
 
-
+__END__
 
 =pod
 
@@ -73,7 +76,7 @@ Markdent::Role::AnyParser - A role for block and span parsers
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -110,15 +113,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
