@@ -1,6 +1,9 @@
 package Markdent::Role::BalancedEvent;
 {
-  $Markdent::Role::BalancedEvent::VERSION = '0.22';
+  $Markdent::Role::BalancedEvent::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::BalancedEvent::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -45,7 +48,7 @@ role {
 
 # ABSTRACT: A parameterized role for events which can check if they match balance another event
 
-
+__END__
 
 =pod
 
@@ -55,7 +58,7 @@ Markdent::Role::BalancedEvent - A parameterized role for events which can check
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -94,15 +97,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
