@@ -1,6 +1,9 @@
 package Markdent::Role::BlockParser;
 {
-  $Markdent::Role::BlockParser::VERSION = '0.22';
+  $Markdent::Role::BlockParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::BlockParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -24,7 +27,7 @@ has _span_parser => (
 
 # ABSTRACT: A role for block parsers
 
-
+__END__
 
 =pod
 
@@ -34,7 +37,7 @@ Markdent::Role::BlockParser - A role for block parsers
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -75,15 +78,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
