@@ -1,6 +1,9 @@
 package Markdent::Role::DebugPrinter;
 {
-  $Markdent::Role::DebugPrinter::VERSION = '0.22';
+  $Markdent::Role::DebugPrinter::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::DebugPrinter::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -44,7 +47,7 @@ sub _print_debug {
 
 # ABSTRACT: A role for classes which output debugging information
 
-
+__END__
 
 =pod
 
@@ -54,7 +57,7 @@ Markdent::Role::DebugPrinter - A role for classes which output debugging informa
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -94,15 +97,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
