@@ -1,6 +1,9 @@
 package Markdent::Role::Dialect::BlockParser;
 {
-  $Markdent::Role::Dialect::BlockParser::VERSION = '0.22';
+  $Markdent::Role::Dialect::BlockParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::Dialect::BlockParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -12,7 +15,7 @@ use Moose::Role;
 
 # ABSTRACT: A role for a dialect block parser
 
-
+__END__
 
 =pod
 
@@ -22,7 +25,7 @@ Markdent::Role::Dialect::BlockParser - A role for a dialect block parser
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -37,15 +40,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
