@@ -1,6 +1,9 @@
 package Markdent::Role::Event;
 {
-  $Markdent::Role::Event::VERSION = '0.22';
+  $Markdent::Role::Event::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::Event::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -146,7 +149,7 @@ sub _debug_value {
 
 # ABSTRACT: Implements behavior shared by all events
 
-
+__END__
 
 =pod
 
@@ -156,7 +159,7 @@ Markdent::Role::Event - Implements behavior shared by all events
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -199,15 +202,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
