@@ -1,6 +1,9 @@
 package Markdent::Role::EventsAsMethods;
 {
-  $Markdent::Role::EventsAsMethods::VERSION = '0.22';
+  $Markdent::Role::EventsAsMethods::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::EventsAsMethods::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -26,7 +29,7 @@ sub handle_event {
 
 # ABSTRACT: Turns events into method calls
 
-
+__END__
 
 =pod
 
@@ -36,7 +39,7 @@ Markdent::Role::EventsAsMethods - Turns events into method calls
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -79,15 +82,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
