@@ -1,6 +1,9 @@
 package Markdent::Role::FilterHandler;
 {
-  $Markdent::Role::FilterHandler::VERSION = '0.22';
+  $Markdent::Role::FilterHandler::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::FilterHandler::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -33,7 +36,7 @@ sub handle_event {
 
 # ABSTRACT: A role for handlers which act as filters
 
-
+__END__
 
 =pod
 
@@ -43,7 +46,7 @@ Markdent::Role::FilterHandler - A role for handlers which act as filters
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -84,15 +87,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
