@@ -1,6 +1,9 @@
 package Markdent::Role::HTMLStream;
 {
-  $Markdent::Role::HTMLStream::VERSION = '0.22';
+  $Markdent::Role::HTMLStream::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::HTMLStream::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -450,7 +453,7 @@ sub print {
 
 # ABSTRACT: A role for handlers which generate HTML
 
-
+__END__
 
 =pod
 
@@ -460,7 +463,7 @@ Markdent::Role::HTMLStream - A role for handlers which generate HTML
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -485,15 +488,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
