@@ -1,6 +1,9 @@
 package Markdent::Role::Handler;
 {
-  $Markdent::Role::Handler::VERSION = '0.22';
+  $Markdent::Role::Handler::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::Handler::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -15,7 +18,7 @@ requires 'handle_event';
 
 # ABSTRACT: A required role for all handlers
 
-
+__END__
 
 =pod
 
@@ -25,7 +28,7 @@ Markdent::Role::Handler - A required role for all handlers
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -50,15 +53,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
