@@ -1,6 +1,9 @@
 package Markdent::Role::SpanParser;
 {
-  $Markdent::Role::SpanParser::VERSION = '0.22';
+  $Markdent::Role::SpanParser::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Role::SpanParser::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -17,7 +20,7 @@ requires 'parse_block';
 
 # ABSTRACT: A role for span parsers
 
-
+__END__
 
 =pod
 
@@ -27,7 +30,7 @@ Markdent::Role::SpanParser - A role for span parsers
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -57,15 +60,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
