@@ -1,6 +1,9 @@
 package Markdent::Simple::Fragment;
 {
-  $Markdent::Simple::Fragment::VERSION = '0.22';
+  $Markdent::Simple::Fragment::VERSION = '0.23';
+}
+BEGIN {
+  $Markdent::Simple::Fragment::AUTHORITY = 'cpan:DROLSKY';
 }
 
 use strict;
@@ -40,7 +43,7 @@ sub markdown_to_html {
 
 # ABSTRACT: Convert Markdown to an HTML Fragment
 
-
+__END__
 
 =pod
 
@@ -50,14 +53,14 @@ Markdent::Simple::Fragment - Convert Markdown to an HTML Fragment
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
     use Markdent::Simple::Fragment;
 
     my $mds  = Markdent::Simple::Fragment->new();
-    my $html = $mss->markdown_to_html(
+    my $html = $mds->markdown_to_html(
         markdown => $markdown,
     );
 
@@ -91,15 +94,15 @@ See L<Markdent> for bug reporting details.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Jason McIntosh <jmac@appleseed-sc.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Dave Rolsky.
+This software is copyright (c) 2013 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
